@@ -1,7 +1,7 @@
 from importlib import import_module
 
 
-__version__ = "0.0.2"
+__version__ = "0.0.5"
 __all__ = []
 
 # Everything we want to be directly importable from under "klass"-package
@@ -29,7 +29,7 @@ local_imports = {
     "classes.family": ["KlassFamily"],
     "classes.search": ["KlassSearchClassifications", "KlassSearchFamilies"],
     "requests.sections": ["sections_list", "sections_dict"],
-    "classes.variant": ["KlassVariant", "KlassVariantCodes"],
+    "classes.variant": ["KlassVariant", "KlassVariantSearchByName"],
     "classes.version": ["KlassVersion"],
     "utility.codes": ["get_codes"],
     "utility.classification": ["get_classification"],
